@@ -19,7 +19,7 @@ from unidist.core.backends.mpi.core.serialization import (
     ComplexDataSerializer,
     SimpleDataSerializer,
 )
-
+import unidist.core.backends.mpi.core.common as common
 
 # TODO: Find a way to move this after all imports
 mpi4py.rc(recv_mprobe=False, initialize=False)
@@ -30,6 +30,53 @@ from mpi4py import MPI  # noqa: E402
 sleep_time = 0.0001
 
 
+# Logger configuration
+logger = common.get_logger("communication", "communication.log")
+is_logger_header_printed = False
+
+
+def log_operation(op_type, status):
+    """
+    Log a communication between worker processes.
+
+    Parameters
+    ----------
+    op_type : unidist.core.backends.mpi.core.common.Operation
+        Operation type.
+    status : mpi4py.MPI.Status
+        Represents the status of a reception operation.
+    """
+    global is_logger_header_printed
+    logger_op_name_len = 15
+    logger_worker_count = MPIState.get_instance().world_size
+
+    # write header on first worker
+    if (
+        not is_logger_header_printed
+        and MPIState.get_instance().rank == MPIRank.FIRST_WORKER
+    ):
+        worker_ids_str = "".join([f"{i}\t" for i in range(logger_worker_count)])
+        logger.debug(f'#{" "*logger_op_name_len}{worker_ids_str}')
+        is_logger_header_printed = True
+
+    # Write operation to log
+    source_rank = status.Get_source()
+    dest_rank = MPIState.get_instance().rank
+    op_name = common.get_op_name(op_type)
+    space_after_op_name = " " * (logger_op_name_len - len(op_name))
+    space_before_arrow = ".   " * (min(source_rank, dest_rank))
+    space_after_arrow = "   ." * (logger_worker_count - max(source_rank, dest_rank) - 1)
+    arrow_line_str = abs(dest_rank - source_rank)
+    # Right arrow if dest_rank > source_rank else left
+    if dest_rank > source_rank:
+        arrow = f'{".---"*arrow_line_str}>'
+    else:
+        arrow = f'<{arrow_line_str*"---."}'
+    logger.debug(
+        f"{op_name}:{space_after_op_name}{space_before_arrow}{arrow}{space_after_arrow}"
+    )
+
+
 class MPIState:
     """
     The class holding MPI information.
@@ -77,6 +124,7 @@ class MPIRank:
 
     ROOT = 0
     MONITOR = 1
+    FIRST_WORKER = 2
 
 
 def get_topology():
@@ -252,6 +300,7 @@ def recv_operation_type(comm):
     while True:
         is_ready, op_type = req_handle.test(status=status)
         if is_ready:
+            log_operation(op_type, status)
             return op_type, status.Get_source()
         else:
             time.sleep(sleep_time)
