@@ -41,6 +41,11 @@ def task(x):
     return x * x
 
 
+@unidist.remote
+def task_return_none():
+    return None
+
+
 @unidist.remote(num_returns=2)
 def task_multiple_returns_default(x):
     return x, x * x
@@ -69,6 +74,9 @@ class TestActor:
         self._internal()
         return self._accumulator
 
+    def task_return_none(self):
+        return None
+
     def multiple_returns(self, x):
         return x, self._accumulator
 
@@ -91,5 +99,8 @@ class TestAsyncActor:
         self._internal()
         return self._accumulator
 
+    async def task_return_none(self):
+        return None
+
     async def multiple_returns(self, x):
         return x, self._accumulator
